# Vue File Uploader

一个支持 Vue 2.x 和 Vue 3.x 的文件上传组件，支持拖拽上传、多文件上传、进度显示等功能。

## 更新日志

### 1.2.0
- ✨ 新增 `clearFiles` 方法用于清空文件列表
- ✨ 新增 `tip` 插槽用于自定义提示信息
- ✨ 新增 `progress` 事件用于监听上传进度
- 🐛 修复 Vue 2.x 环境下的类型定义问题
- 🐛 修复文件大小限制的错误处理
- 📦 优化 ESM 和 CommonJS 模块导出
- 📝 完善 TypeScript 类型定义

### 1.0.0
- 🎯 初始版本发布
- ✨ 支持 Vue 2.x 和 Vue 3.x
- ✨ 支持点击和拖拽上传
- ✨ 支持单文件和多文件上传
- ✨ 支持文件类型和大小限制
- ✨ 支持自定义上传区域
- ✨ 支持上传进度显示
- 💪 使用 TypeScript 编写，提供完整的类型定义

## 特性

- 🎯 支持 Vue 2.x 和 Vue 3.x
- 🚀 支持点击和拖拽上传
- 📦 支持单文件和多文件上传
- 📊 实时显示上传进度
- 🎨 美观的 UI 和动画效果
- 🔧 高度可定制的界面
- 💪 使用 TypeScript 编写，提供完整的类型定义
- 📦 支持 ESM 和 CommonJS 两种模块规范

## 安装

```bash
# Vue 3.x
npm install @saberlayer/vue-file-uploader

# Vue 2.x - 需要同时安装 composition-api
npm install @saberlayer/vue-file-uploader @vue/composition-api
```

## 使用方法

### ESM 导入

```typescript
// Vue 3.x
import { FileUploader } from '@saberlayer/vue-file-uploader'
import '@saberlayer/vue-file-uploader/dist/vue-file-uploader.css'

// Vue 2.x
import Vue from 'vue'
import VueCompositionAPI from '@vue/composition-api'
import { FileUploader } from '@saberlayer/vue-file-uploader'
import '@saberlayer/vue-file-uploader/dist/vue-file-uploader.css'

Vue.use(VueCompositionAPI)
```

### CommonJS 导入

```javascript
// Vue 3.x
const { FileUploader } = require('@saberlayer/vue-file-uploader')
require('@saberlayer/vue-file-uploader/dist/vue-file-uploader.css')

// Vue 2.x
const Vue = require('vue')
const VueCompositionAPI = require('@vue/composition-api')
const { FileUploader } = require('@saberlayer/vue-file-uploader')
require('@saberlayer/vue-file-uploader/dist/vue-file-uploader.css')

Vue.use(VueCompositionAPI)
```

### 全局注册

```typescript
// Vue 3.x
import { createApp } from 'vue'
import { FileUploader } from '@saberlayer/vue-file-uploader'
import '@saberlayer/vue-file-uploader/dist/vue-file-uploader.css'

const app = createApp(App)
app.component('FileUploader', FileUploader)
app.mount('#app')

// Vue 2.x
import Vue from 'vue'
import VueCompositionAPI from '@vue/composition-api'
import { FileUploader } from '@saberlayer/vue-file-uploader'
import '@saberlayer/vue-file-uploader/dist/vue-file-uploader.css'

Vue.use(VueCompositionAPI)
Vue.component('FileUploader', FileUploader)
```

### 局部注册

```typescript
// Vue 3.x 或 Vue 2.x + Composition API
import { FileUploader } from '@saberlayer/vue-file-uploader'
import '@saberlayer/vue-file-uploader/dist/vue-file-uploader.css'

export default {
  components: {
    FileUploader
  }
}
```

### TypeScript 类型导入

```typescript
import type { UploadFile, FileUploaderProps, FileUploaderEmits } from '@saberlayer/vue-file-uploader'
```

### 基础用法

```vue
<template>
  <file-uploader
    action="https://your-upload-url.com/upload"
    @change="handleChange"
    @success="handleSuccess"
    @error="handleError"
  />
</template>

<script lang="ts">
import { defineComponent } from 'vue'
import type { UploadFile } from '@saberlayer/vue-file-uploader'

export default defineComponent({
  setup() {
    const handleChange = ({ file, fileList }: { file: UploadFile; fileList: UploadFile[] }) => {
      console.log('文件变化：', file, fileList)
    }

    const handleSuccess = (file: UploadFile, fileList: UploadFile[]) => {
      console.log('上传成功：', file)
    }

    const handleError = (error: Error, file: UploadFile) => {
      console.log('上传失败：', error)
    }

    return {
      handleChange,
      handleSuccess,
      handleError
    }
  }
})
</script>
```

### 限制文件大小和类型

```vue
<template>
  <file-uploader
    action="https://your-upload-url.com/upload"
    :max-size="1024 * 1024" <!-- 1MB -->
    :max-count="2"
    accept=".jpg,.png,.pdf"
    @exceed="handleExceed"
  />
</template>

<script lang="ts">
import { defineComponent } from 'vue'

export default defineComponent({
  setup() {
    const handleExceed = (files: File[]) => {
      alert('超出文件限制！')
    }

    return {
      handleExceed
    }
  }
})
</script>
```

### 自定义上传区域

```vue
<template>
  <file-uploader
    ref="uploader"
    action="https://your-upload-url.com/upload"
    :auto-upload="false"
  >
    <template #default>
      <div class="custom-upload-area">
        <button @click="$refs.uploader.handleClick()">
          选择文件
        </button>
        <p>支持点击或拖拽上传</p>
      </div>
    </template>
  </file-uploader>
  <button @click="$refs.uploader.submit()">
    开始上传
  </button>
</template>
```

## API

### Props

| 参数 | 说明 | 类型 | 默认值 |
|------|------|------|--------|
| action | 上传的地址（必填） | string | - |
| multiple | 是否支持多文件上传 | boolean | false |
| accept | 接受的文件类型 | string | - |
| maxSize | 文件大小限制（字节） | number | 0 |
| maxCount | 文件数量限制 | number | 0 |
| headers | 上传请求头 | Record<string, string> | {} |
| data | 上传时附带的额外参数 | Record<string, any> | {} |
| autoUpload | 是否在选择文件后自动上传 | boolean | true |
| fileList | 已上传的文件列表 | UploadFile[] | [] |
| disabled | 是否禁用上传 | boolean | false |
| drag | 是否启用拖拽上传 | boolean | false |

### Events

| 事件名 | 说明 | 回调参数 |
|--------|------|----------|
| change | 文件状态改变时触发 | { file: UploadFile; fileList: UploadFile[] } |
| success | 文件上传成功时触发 | (file: UploadFile, fileList: UploadFile[]) |
| error | 文件上传失败时触发 | (error: Error, file: UploadFile) |
| exceed | 超出文件数量或大小限制时触发 | (files: File[]) |
| progress | 上传进度变化时触发 | (file: UploadFile, percentage: number) |

### Methods

| 方法名 | 说明 | 参数 |
|--------|------|------|
| submit | 手动上传文件 | - |
| handleClick | 手动触发文件选择 | - |
| clearFiles | 清空文件列表 | - |

### Slots

| 插槽名 | 说明 |
|--------|------|
| default | 自定义上传区域的内容 |
| tip | 自定义提示信息 |

## 浏览器支持

- Chrome >= 51
- Firefox >= 53
- Safari >= 10
- Edge >= 79

## 开发

```bash
# 安装依赖
npm install

# 开发模式
npm run dev

# 构建 Vue 2.x 版本
npm run build:v2

# 构建 Vue 3.x 版本
npm run build:v3

# 构建所有版本
npm run build

# 运行示例
npm run demo

# 运行测试
npm run test
```

## 常见问题

### 1. Vue 2.x 环境下报错 "Composition API is not available"

确保已安装并注册 `@vue/composition-api`：

```javascript
import Vue from 'vue'
import VueCompositionAPI from '@vue/composition-api'

Vue.use(VueCompositionAPI)
```

### 2. 文件上传失败

检查以下几点：
- 上传地址 `action` 是否正确
- 服务器是否支持跨域请求
- 文件大小是否超出限制
- 网络连接是否正常

### 3. IE 11 兼容性问题

需要添加以下 polyfill：
- `core-js`
- `regenerator-runtime`

## License

MIT 